@@ -57,6 +57,10 @@ urlpatterns = patterns('',
 
     url(r'^$', generic.dashboard, name='sentry'),
     url(r'^manage/status/$', admin.status, name='sentry-admin-status'),
+    url(r'^manage/users/$', admin.manage_users, name='sentry-admin-users'),
+    url(r'^manage/users/new/$', admin.create_new_user, name='sentry-admin-new-user'),
+    url(r'^manage/users/(?P<user_id>\d+)/$', admin.edit_user, name='sentry-admin-edit-user'),
+    url(r'^manage/users/(?P<user_id>\d+)/remove/$', admin.remove_user, name='sentry-admin-remove-user'),
     url(r'^manage/plugins/(?P<slug>[\w_-]+)/$', admin.configure_plugin, name='sentry-admin-configure-plugin'),
 
     # API / JS
